translate.convert.csv2tbx.csv2tbx

Package translate :: Package convert :: Module csv2tbx :: Class csv2tbx |
[hide private]
[frames] | no frames]

# Class csv2tbx

source code

a class that takes translations from a .csv file and puts them in a .tbx file

Instance Methods | [hide private]
__init__(self, charset=None) construct the converter... | source code
convertfile(self, thecsvfile) converts a csvfile to a tbxfile, and returns it. | source code

Method Details | [hide private]

### convertfile(self, thecsvfile) | source code
converts a csvfile to a tbxfile, and returns it. uses templatepo if given at construction